Carrot Compatible API - kombu.compat — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Carrot Compatible API - kombu.compat

class `kombu.compat.` `Consumer`(connection, queue=None, exchange=None, routing_key=None, exchange_type=None, durable=None, exclusive=None, auto_delete=None, **kwargs)
  `close`()
  `discard_all`(filterfunc=None)
  `fetch`(no_ack=None, enable_callbacks=False)
  `iterconsume`(limit=None, no_ack=None)
  `iterqueue`(limit=None, infinite=False)
  `process_next`()
  `wait`(limit=None)

`kombu.compat.` `ConsumerSet`(connection, from_dict=None, consumers=None, callbacks=None, **kwargs)

class `kombu.compat.` `Publisher`(connection, exchange=None, routing_key=None, exchange_type=None, durable=None, auto_delete=None, **kwargs)
  `close`()
  `send`(*args, **kwargs)

`kombu.compat.` `entry_to_queue`(queue, **options)

`kombu.compat.` `iterconsume`(connection, consumer, no_ack=False, limit=None)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »